import json
from typing import Union
from tesselite import App
from tesselite.exceptions import MessageProcessingException


class Message:

    content: dict | None # message content as map

    def __init__(self, content: Union [str, dict]):
        if isinstance(content, str):
            self.content = json.loads(content)
        elif isinstance(content, dict):
            self.content = content
        else:
            App.Logger.error(f"unsupported message type: {type(content)}")
            raise MessageProcessingException(content)

    def serialize(self) -> str:
        return json.dumps(self.content)

    @classmethod
    def deserialize(cls, message: str):
        return cls(message)



import os.path
import unittest
from pathlib import Path

def runSuite():
    tests_dir = Path(os.path.dirname(__file__))
    tests = unittest.TestLoader()
    suite = tests.discover(tests_dir.as_posix())
    runner = unittest.TextTestRunner()
    runner.run(suite)

if __name__ == '__main__':
    runSuite()



import abc
import unittest


class TestKafkaPubsub(unittest.TestCase):

    def test_import(self):

        from tesselite.pubsub import KafkaPubSub

        assert isinstance(KafkaPubSub, abc.ABCMeta)

    def test_publish(self):
        assert True  # add assertion here

    def test_consume(self):
        assert True  # add assertion here

if __name__ == '__main__':
    unittest.main()
